PlayerColor

Enum PlayerColor 

pub enum PlayerColor {
    Black,
    White,
}
Defines the two player colors of a chess game Black and White.

Variants



Black



White

Implementations

Source

impl PlayerColor

pub fn reverse(&self) -> PlayerColor

Returns the player color not currently represented by self.

  • returns - The reversed player color