pub enum PlayerColor {
Black,
White,
}Expand description
Defines the two player colors of a chess game Black and White.
Variants
Implementations
Sourceimpl PlayerColor
impl PlayerColor
Sourcepub fn reverse(&self) -> PlayerColor
pub fn reverse(&self) -> PlayerColor
Returns the player color not currently represented by self.
returns- The reversed player color